@@ -72,8 +72,8 @@ class ProxyMethod(object):
             # TODO: Could there ever have been a value here that needs to be restored?
             del self._target.obj.__dict__[self._method_name]
 
-        if self._method_name == '__call__':
-            self._target.restore__call__()
+        if self._method_name in ['__call__', '__enter__', '__exit__']:
+            self._target.restore_attr(self._method_name)
 
     def _capture_original_method(self):
         """Saves a reference to the original value of the method to be doubled."""
@@ -95,8 +95,8 @@ class ProxyMethod(object):
         else:
             self._target.obj.__dict__[self._method_name] = self
 
-        if self._method_name == '__call__':
-            self._target.hijack__call__()
+        if self._method_name in ['__call__', '__enter__', '__exit__']:
+            self._target.hijack_attr(self._method_name)
 
     def _raise_exception(self, args, kwargs):
         """
@@ -105,8 +105,12 @@ class ProxyMethod(object):
         :raise: ``UnallowedMethodCallError``
         """
 
+        error_message = (
+            "Received unexpected call to '{}' on {!r}.  The supplied arguments "
+            "(args={}, kwargs={}) do not match any available allowances."
+        )
         raise UnallowedMethodCallError(
-            "Received unexpected call to '{}' on {!r} with (args={}, kwargs={}).".format(
+            error_message.format(
                 self._method_name,
                 self._target.obj,
                 args,
